@@ -2,17 +2,19 @@ import warnings
 
 from flask import Flask
 from flask.ext.bootstrap import Bootstrap
-from webgrid.flask import FlaskSQLAlchemyManager, webgrid
+
+from webgrid.flask import WebGrid
 
 # ignore warning about Decimal lossy conversion with SQLite from SA
 warnings.filterwarnings('ignore', '.*support Decimal objects natively.*')
 
-fsam = FlaskSQLAlchemyManager()
+webgrid = WebGrid()
+
 
 def create_app(config):
     app = Flask(__name__)
 
-    app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:////tmp/webgrid.db'
+    app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///'
     #app.config['SQLALCHEMY_ECHO'] = True
     #app.config['DEBUG'] = True
     if config == 'Test':
@@ -21,13 +23,12 @@ def create_app(config):
 
     from webgrid_ta.model import db
     db.init_app(app)
-    fsam.init_db(db)
+    webgrid.init_db(db)
     Bootstrap(app)
-    app.register_blueprint(webgrid)
+    webgrid.init_app(app)
 
     from .views import main
     app.register_blueprint(main)
 
     return app
 
-
